==> mysql-workbench-gpl-5.2.35-src.tar.gz: mysql-workbench-gpl-5.2.35-src/library/forms/appview.cpp <==
/* 
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#include "stdafx.h"

#include <mforms/appview.h>
#include <mforms/mforms.h>
#include <mforms/toolbar.h>

using namespace mforms;

//--------------------------------------------------------------------------------------------------

#ifdef _WIN32

AppView::AppView(bool horiz, const std::string &context_name, bool is_main)
  : Box(horiz), _context_name(context_name), _menubar(0), _toolbar(0), _is_main(is_main)
{
  _app_view_impl= &ControlFactory::get_instance()->_app_view_impl;
  if (_app_view_impl && _app_view_impl->create)
    _app_view_impl->create(this, horiz);
}

#else

AppView::AppView(bool horiz, const std::string &context_name, bool is_main) 
: Box(horiz), _context_name(context_name), _menubar(0), _toolbar(0), _is_main(is_main)
{
#ifdef __APPLE__
  // default, empty toolbar for mac, to show the 3px bar under the top tabs
  _toolbar = new mforms::ToolBar(mforms::MainToolBar);
#endif
}

#endif

//--------------------------------------------------------------------------------------------------

AppView::~AppView()
{
  if (_menubar)
    _menubar->release();
  if (_toolbar)
    _toolbar->release();
}

//--------------------------------------------------------------------------------------------------

void AppView::set_menubar(mforms::MenuBar *menu)
{
  if (_menubar != menu)
  {
    if (_menubar)
      _menubar->release();
    _menubar = menu;
    if (menu)
      _menubar->retain();
  }
}

//--------------------------------------------------------------------------------------------------

void AppView::set_toolbar(mforms::ToolBar *toolbar)
{
  if (_toolbar != toolbar)
  {
    if (_toolbar)
      _toolbar->release();
    _toolbar = toolbar;
    if (toolbar)
      _toolbar->retain();
  }
}

==> mysql-workbench-gpl-5.2.44-src.tar.gz: mysql-workbench-gpl-5.2.44-src/library/forms/appview.cpp <==
/* 
 * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#include "stdafx.h"

#include "base/string_utilities.h"

#include "mforms/mforms.h"

using namespace mforms;

//--------------------------------------------------------------------------------------------------
static int _serial = 0;

#ifdef _WIN32

AppView::AppView(bool horiz, const std::string &context_name, bool is_main)
  : Box(horiz), _context_name(context_name), _menubar(0), _toolbar(0), _is_main(is_main)
{
  _app_view_impl= &ControlFactory::get_instance()->_app_view_impl;
  if (_app_view_impl && _app_view_impl->create)
    _app_view_impl->create(this, horiz);
  
  _identifier = base::strfmt("avid%i", ++_serial);
}

#else

AppView::AppView(bool horiz, const std::string &context_name, bool is_main) 
: Box(horiz), _context_name(context_name), _menubar(0), _toolbar(0), _is_main(is_main)
{
#ifdef __APPLE__
  // default, empty toolbar for mac, to show the 3px bar under the top tabs
  _toolbar = new mforms::ToolBar(mforms::MainToolBar);
#endif
  _identifier = base::strfmt("avid%i", ++_serial);
}

#endif

//--------------------------------------------------------------------------------------------------

AppView::~AppView()
{
  if (_menubar)
    _menubar->release();
  if (_toolbar)
    _toolbar->release();
}

//--------------------------------------------------------------------------------------------------

void AppView::set_menubar(mforms::MenuBar *menu)
{
  if (_menubar != menu)
  {
    if (_menubar)
      _menubar->release();
    _menubar = menu;
    if (menu)
      _menubar->retain();
  }
}

//--------------------------------------------------------------------------------------------------

void AppView::set_toolbar(mforms::ToolBar *toolbar)
{
  if (_toolbar != toolbar)
  {
    if (_toolbar)
      _toolbar->release();
    _toolbar = toolbar;
    if (toolbar)
      _toolbar->retain();
  }
}

//--------------------------------------------------------------------------------------------------

void AppView::set_title(const std::string &title)
{ 
  _title= title;
  //XXX remove this callback and make it send a notification
  App::get()->set_view_title(this, title); 
}

//--------------------------------------------------------------------------------------------------

std::string AppView::get_title()
{
  return _title;
}

bool AppView::on_close()
{
  if (_on_close_slot) 
    return _on_close_slot(); 
  return true;
}
